==> 1.0.0.tar.gz: lib/src/top_level/Uries.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../lists/DottedIdentifierList.dart';
import '../sub_types/Literals.dart';

/*
<uri> ::= <stringLiteral>

See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
Page 174
*/
class Uri extends ParserType {
  StringLiteral stringLiteral;

  Uri(Lexer lexer) {
    stringLiteral = StringLiteral(lexer);
  }

  String toString() {
    return '$stringLiteral';
  }
  
}

/* <configurableUri> ::= <uri> <configurationUri>* */
class ConfigurableUri extends ParserType {
  Uri uri;
  List<ConfigurationUri> configurationUries;

  ConfigurableUri(Lexer lexer) {
    configurationUries = [];

    uri = Uri(lexer);

    int snapShot;
    try {
      while (true) {
        snapShot = lexer.currentIndex;
        configurationUries.add(ConfigurationUri(lexer));
      }
    }
    on WrongTokenType {
      lexer.setPos(snapShot);
    }

  }

  String toString() {
    String rtn = '$uri';
    configurationUries.forEach((u) => rtn += ' $u');
    return rtn;
  }
  
}

/* <configurationUri> ::= if '(' <uriTest> ')' <uri> */
class ConfigurationUri extends ParserType {
  UriTest uriTest;
  Uri uri;

  ConfigurationUri(Lexer lexer) {
    checkType(lexer, TType.KEYWORD);
    checkVal(lexer, 'if');
    lexer.advance();

    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    uriTest = UriTest(lexer);

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();

    uri = Uri(lexer);
  }

  String toString() {
    return 'if ($uriTest) $uri';
  }
  
}

/* <uriTest> ::= <dottedIdentifierList> ('==' <stringLiteral>)? */
class UriTest extends ParserType {
  DottedIdentifierList dottedIdentifierList;
  StringLiteral stringLiteral;

  UriTest(Lexer lexer) {
    dottedIdentifierList = DottedIdentifierList(lexer);

    int snapShot = lexer.currentIndex;
    try {
      checkType(lexer, TType.EQUALS);
      lexer.advance();
      checkType(lexer, TType.EQUALS);
      lexer.advance();

      stringLiteral = StringLiteral(lexer);
    }
    on WrongTokenType {
      lexer.setPos(snapShot);
    }

  }

  String toString() {
    return '$dottedIdentifierList' + (stringLiteral != null ? ' == $stringLiteral' : '');
  }
  
}

==> 1.1.1.tar.gz: lib/src/top_level/Uries.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../lists/DottedIdentifierList.dart';
import '../sub_types/Literals.dart';

/// <uri> ::= <stringLiteral>
///
/// See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
/// Page 174
class Uri extends ParserType {
  StringLiteral stringLiteral;

  Uri(Lexer lexer) {
    stringLiteral = StringLiteral(lexer);
  }

  String toString() {
    return '$stringLiteral';
  }
}

/// <configurableUri> ::= <uri> <configurationUri>*
class ConfigurableUri extends ParserType {
  Uri uri;
  List<ConfigurationUri> configurationUries;

  ConfigurableUri(Lexer lexer) {
    configurationUries = [];

    uri = Uri(lexer);

    int snapShot;
    try {
      while (true) {
        snapShot = lexer.currentIndex;
        configurationUries.add(ConfigurationUri(lexer));
      }
    } on WrongTokenType {
      lexer.setPos(snapShot);
    }
  }

  String toString() {
    String rtn = '$uri';
    configurationUries.forEach((u) => rtn += ' $u');
    return rtn;
  }
}

/// <configurationUri> ::= if '(' <uriTest> ')' <uri>
class ConfigurationUri extends ParserType {
  UriTest uriTest;
  Uri uri;

  ConfigurationUri(Lexer lexer) {
    checkType(lexer, TType.KEYWORD);
    checkVal(lexer, 'if');
    lexer.advance();

    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    uriTest = UriTest(lexer);

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();

    uri = Uri(lexer);
  }

  String toString() {
    return 'if ($uriTest) $uri';
  }
}

/// <uriTest> ::= <dottedIdentifierList> ('==' <stringLiteral>)?
class UriTest extends ParserType {
  DottedIdentifierList dottedIdentifierList;
  StringLiteral stringLiteral;

  UriTest(Lexer lexer) {
    dottedIdentifierList = DottedIdentifierList(lexer);

    int snapShot = lexer.currentIndex;
    try {
      checkType(lexer, TType.EQUALS);
      lexer.advance();
      checkType(lexer, TType.EQUALS);
      lexer.advance();

      stringLiteral = StringLiteral(lexer);
    } on WrongTokenType {
      lexer.setPos(snapShot);
    }
  }

  String toString() {
    return '$dottedIdentifierList' +
        (stringLiteral != null ? ' == $stringLiteral' : '');
  }
}
